@@ -5,6 +5,7 @@
 #include "Bunker.h"
 #include "HiScores.h"
 #include "HiScoreModel.h"
+#include "Helper.h"
 
 int main(int argc, char *argv[])
 {
@@ -17,9 +18,11 @@ int main(int argc, char *argv[])
     QmlApplicationViewer viewer;
     HiScores hiscores;
     HiScoreModel globalhiscores;
+    Helper helper;
 
     viewer.rootContext()->setContextProperty("HiScores", &hiscores);
     viewer.rootContext()->setContextProperty("GlobalHiScores", &globalhiscores);
+    viewer.rootContext()->setContextProperty("Helper", &helper);
 
     viewer.setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
 
